# Overview

Suppose someone writes you an email. It shows up in your linked inbox like this:

<!-- <img width="603" alt="image" src="https://github.com/user-attachments/assets/ad808e86-1878-499c-b45e-61a4aa74c0ac"> -->

<img width="645" alt="image" src="https://github.com/user-attachments/assets/74f6db50-1034-4c5f-b636-6dc63447df04">

While it's still unread, the Epistolary library will download it and convert it to a PDF. Depending on your document-manager, it will be uploaded to a destination of your choice. In this case, it's uploaded to my reMarkable tablet:

![image](https://github.com/user-attachments/assets/4d8cefb1-a57d-443a-878c-5bf9d4b664af)

<img width="632" alt="image" src="https://github.com/user-attachments/assets/ea72ad77-b2ff-44c3-ae8e-9e7359588187">

You can then write a reply in handwriting:

![image](https://github.com/user-attachments/assets/4c6ef9f0-3d31-4c87-9faf-1d7484901bc9)

Once you're done, move the file to the Outbox to mark it ready to be posted. Epistolary will then transcribe the text and send the email back to the originating address as a Reply.

Here's how it appears to the recipient:

---

![image](https://github.com/user-attachments/assets/fc7e5c75-ddad-4d73-ab3e-56d5f5c2725f)
